@@ -4,7 +4,9 @@ use warnings;
 
 require 5.008_001;
 
-our $VERSION = '0.40';
+# ABSTRACT: SAML2 bindings and protocol implementation
+
+our $VERSION = '0.43';
 $VERSION = eval {$VERSION};
 
 
@@ -35,11 +37,11 @@ __END__
 
 =head1 NAME
 
-Net::SAML2
+Net::SAML2 - SAML2 bindings and protocol implementation
 
 =head1 VERSION
 
-version 0.40
+version 0.43
 
 =head1 SYNOPSIS
 
@@ -128,6 +130,8 @@ Identity Providers (IdPs).  It has been tested against:
 
 =item Auth0 (requires Net::SAML2 >=0.39)
 
+=item PingIdentity
+
 =back
 
 =head1 NAME
