@@ -5,6 +5,10 @@ use warnings;
 
 use Moose;
 
+our $VERSION = '0.43';
+
+# ABSTRACT: Net::SAML2::Binding::POST - HTTP POST binding for SAML
+
 
 use Net::SAML2::XML::Sig;
 use MIME::Base64 qw/ decode_base64 /;
@@ -53,11 +57,11 @@ __END__
 
 =head1 NAME
 
-Net::SAML2::Binding::POST
+Net::SAML2::Binding::POST - Net::SAML2::Binding::POST - HTTP POST binding for SAML
 
 =head1 VERSION
 
-version 0.40
+version 0.43
 
 =head1 SYNOPSIS
 
