@@ -2,6 +2,10 @@ package Net::SAML2::IdP;
 use Moose;
 use MooseX::Types::URI qw/ Uri /;
 
+our $VERSION = '0.43';
+
+# ABSTRACT: Net::SAML2::IdP - SAML Identity Provider object
+
 
 use Crypt::OpenSSL::Verify;
 use Crypt::OpenSSL::X509;
@@ -18,7 +22,9 @@ has 'slo_urls' => (isa => 'Maybe[HashRef[Str]]', is => 'ro');
 has 'art_urls' => (isa => 'Maybe[HashRef[Str]]', is => 'ro');
 has 'certs'    => (isa => 'HashRef[Str]',        is => 'ro', required => 1);
 has 'formats'  => (isa => 'HashRef[Str]',        is => 'ro', required => 1);
-has 'default_format' => (isa => 'Str', is => 'ro', required => 1);
+has 'sls_force_lcase_url_encoding'    => (isa => 'Bool', is => 'ro', required => 0);
+has 'sls_double_encoded_response' => (isa => 'Bool', is => 'ro', required => 0);
+has 'default_format'          => (isa => 'Str',  is => 'ro', required => 1);
 
 
 sub new_from_url {
@@ -40,7 +46,12 @@ sub new_from_url {
 
     my $xml = $res->content;
 
-    return $class->new_from_xml(xml => $xml, cacert => $args{cacert});
+    return $class->new_from_xml(
+                    xml => $xml,
+                    cacert => $args{cacert},
+                    sls_force_lcase_url_encoding => $args{sls_force_lcase_url_encoding},
+                    sls_double_encoded_response => $args{sls_double_encoded_response},
+                    );
 }
 
 
@@ -140,6 +151,8 @@ sub new_from_xml {
         formats        => $data->{NameIDFormat},
         default_format => $data->{DefaultFormat},
         cacert         => $args{cacert},
+        sls_force_lcase_url_encoding => $args{sls_force_lcase_url_encoding},
+        sls_double_encoded_response => $args{sls_double_encoded_response},
     );
 
     return $self;
@@ -227,11 +240,11 @@ __END__
 
 =head1 NAME
 
-Net::SAML2::IdP
+Net::SAML2::IdP - Net::SAML2::IdP - SAML Identity Provider object
 
 =head1 VERSION
 
-version 0.40
+version 0.43
 
 =head1 SYNOPSIS
 
@@ -261,6 +274,18 @@ Constructor
 
 =item B<entityid>
 
+=item B<sls_force_lcase_url_encoding>
+
+Specifies that the IdP requires the encoding of a URL to be in lowercase.
+Necessary for a HTTP-Redirect of a LogoutResponse from Azure in particular.
+True (1) or False (0). Some web frameworks and underlying http requests assume
+that the encoding should be in the standard uppercase (%2F not %2f)
+
+=item B<sls_double_encoded_response>
+
+Specifies that the IdP response sent to the HTTP-Redirect is double encoded.
+The double encoding requires it to be decoded prior to processing.
+
 =back
 
 =head2 new_from_url( url => $url, cacert => $cacert, ssl_opts => {} )
