@@ -6,10 +6,15 @@ use Net::SAML2::XML::Util qw/ no_comments /;
 
 with 'Net::SAML2::Role::ProtocolMessage';
 
+# ABSTRACT: SAML2 LogoutRequest Protocol object
+
+our $VERSION = '0.43';
+
 
 has 'session'       => (isa => NonEmptySimpleStr, is => 'ro', required => 1);
 has 'nameid'        => (isa => NonEmptySimpleStr, is => 'ro', required => 1);
 has 'nameid_format' => (isa => NonEmptySimpleStr, is => 'ro', required => 1);
+has 'destination'   => (isa => NonEmptySimpleStr, is => 'ro', required => 0);
 
 
 sub new_from_xml {
@@ -46,6 +51,7 @@ sub as_xml {
             $samlp,
             { ID => $self->id,
               IssueInstant => $self->issue_instant,
+              Destination => $self->destination,
               Version => '2.0' },
             $x->Issuer(
                 $saml,
@@ -76,11 +82,11 @@ __END__
 
 =head1 NAME
 
-Net::SAML2::Protocol::LogoutRequest
+Net::SAML2::Protocol::LogoutRequest - SAML2 LogoutRequest Protocol object
 
 =head1 VERSION
 
-version 0.40
+version 0.43
 
 =head1 SYNOPSIS
 
@@ -123,7 +129,8 @@ SP's identity URI
 
 =item B<destination>
 
-IdP's identity URI
+IdP's identity URI this is required for a signed message but likely should be
+sent regardless
 
 =back
 
