@@ -9,7 +9,7 @@ use XML::LibXML;
 use vars qw($VERSION @EXPORT_OK %EXPORT_TAGS $DEBUG);
 
 $DEBUG = 0;
-$VERSION = '0.40';
+our $VERSION = '0.43';
 
 # We are exporting functions
 use base qw/Exporter/;
@@ -17,6 +17,8 @@ use base qw/Exporter/;
 # Export list - to allow fine tuning of export table
 @EXPORT_OK = qw( no_comments );
 
+# ABSTRACT: Net::SAML2::XML::Util - XML Util class
+
 
 
 sub no_comments {
@@ -46,11 +48,11 @@ __END__
 
 =head1 NAME
 
-Net::SAML2::XML::Util
+Net::SAML2::XML::Util - Net::SAML2::XML::Util - XML Util class
 
 =head1 VERSION
 
-version 0.40
+version 0.43
 
 =head1 SYNOPSIS
 
